Learn R Programming

prodest (version 1.0.2)

FSres: Generate the vector of the first stage residuals

Description

This method provides the way to estimate the first stage residuals from a prod S4 object - estimates from prodestOP, prodestLP, prodestACF, prodestWRDG and prodestWRDG_GMM - defined in the prodest package

Usage

FSres(object)

Arguments

object

object of class prod.

Author

Gabriele Rovigatti

Details

FSres accepts an S4 prod object and returns the vector of firs stage residuals.