An R object. Can be a matrix/dataframe/vector/scalar.
Author
Gabriele Rovigatti
Details
checkM() accepts one input and - if input is a matrix - returns it without column names, otherwise transforms it into a matrix and returns it without column names.