Learn R Programming

prodest (version 1.0.2)

coef: Print the estimated parameters

Description

This method provides the way to extract and print the estimated parameters from a prod S4 object - estimates from prodestOP, prodestLP, prodestACF, prodestWRDG and prodestWRDG_GMM - defined in the prodest package

Usage

coef(object,...)

Arguments

object

object of class prod.

...

Additional arguments.

Author

Gabriele Rovigatti

Details

coef accepts an S4 prod object and prints the vector of estimated parameters.