powered by
This method provides the way to estimate the omega residuals from a prod S4 object - estimates from prodestOP, prodestLP, prodestACF, prodestWRDG and prodestWRDG_GMM - defined in the prodest package
S4
prodest
omega(object)
object of class prod.
A vector of productivity estimates - omega.
omega accepts an S4 prod object and returns a vector of omega estimates.
omega