This method allows the user to print a table with a summary of the results within an S4 prod object: the parameter estimates, the method, the number of observations, the time elapsed, the number of bootstrap repetitions, the first stage estimates and the starting points.
# S4 method for prod
summary(object, ...)
object of class prod.
Additional arguments.
Gabriele Rovigatti
summary accepts an S4 prod object and prints a table with the results.